@@ -7,4 +7,4 @@ currentdir = os.path.abspath(os.path.dirname(__file__))
 sys.path.append(currentdir)
 
 # local imports 
-from em import EM
\ No newline at end of file
+from vgem.em import EM
\ No newline at end of file
