@@ -2,8 +2,11 @@
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import padding
 
-def encrypt_public(message, public_key):
-    message = message.encode('utf-8') # encrypting requires binary
+def encrypt_public(message, public_key, code=True):
+    
+    if code:
+        message = message.encode('utf-8') # encrypting requires binary
+
     encrypted_message = public_key.encrypt(
         message,
         padding.OAEP(
